@@ -7,11 +7,20 @@ source .env
 CURRENT_VERSION=$(grep -E '^version = ' pyproject.toml | cut -d'"' -f2)
 echo "Current version: $CURRENT_VERSION"
 
-# Ask for new version
-read -p "Enter new version (or press Enter to keep $CURRENT_VERSION): " NEW_VERSION
+# Calculate auto-increment version (patch version +1)
+IFS='.' read -r major minor patch <<< "$CURRENT_VERSION"
+AUTO_VERSION="$major.$minor.$((patch + 1))"
 
-# Update version if provided
-if [ ! -z "$NEW_VERSION" ]; then
+# Ask for new version
+read -p "Enter new version (or press Enter for $AUTO_VERSION): " NEW_VERSION
+
+# Use auto-increment if no input provided
+if [ -z "$NEW_VERSION" ]; then
+    NEW_VERSION=$AUTO_VERSION
+fi
+
+# Update version in pyproject.toml
+if [ "$NEW_VERSION" != "$CURRENT_VERSION" ]; then
     if [[ "$OSTYPE" == "darwin"* ]]; then
         # macOS
         sed -i '' "s/^version = \".*\"/version = \"$NEW_VERSION\"/" pyproject.toml
@@ -21,7 +30,7 @@ if [ ! -z "$NEW_VERSION" ]; then
     fi
     echo "Updated version to: $NEW_VERSION"
 else
-    NEW_VERSION=$CURRENT_VERSION
+    echo "Keeping version: $NEW_VERSION"
 fi
 
 # Clean previous builds
